==> react-native-sj-prime-base-0.0.50.tgz: package/src/library/bottom-navigation.tsx <==
import { View } from 'react-native';
import { useLinkBuilder } from '@react-navigation/native';
import { PlatformPressable } from '@react-navigation/elements';
import React, { ReactNode } from 'react';
import MenuItem from './menu-item';

interface BottomNavigationProps {
  state: any;
  descriptors: any;
  navigation: any;
  config: {
    [key: string]: {
      active: ReactNode;
      inactive: ReactNode;
      title: string;
      order: number;
      badge?: {
        variant: 'dot' | 'new' | 'number';
        count?: number;
      };
    };
  };
  shadow?: boolean;
  divider?: boolean;
}

const BottomNavigation = ({
  state,
  descriptors,
  navigation,
  config,
  shadow = false,
  divider = false,
}: BottomNavigationProps) => {
  const { buildHref } = useLinkBuilder();
  const dividerClassFlag = divider ? 'border-t border-gray-100' : '';

  // order 기준으로 routes 정렬
  const sortedRoutes = [...state.routes].sort(
    (a, b) => config[a.name].order - config[b.name].order,
  );

  return (
    <View className="h-[86px]" style={{ flexDirection: 'row' }}>
      {sortedRoutes.map((route, index) => {
        const routeConfig = config[route.name];
        const isFocused =
          state.index === state.routes.findIndex((r) => r.key === route.key);

        const onPress = () => {
          const event = navigation.emit({
            type: 'tabPress',
            target: route.key,
            canPreventDefault: true,
          });

          if (!isFocused && !event.defaultPrevented) {
            navigation.navigate(route.name, route.params);
          }
        };

        return (
          <PlatformPressable
            key={route.key}
            pressOpacity={1}
            href={buildHref(route.name, route.params)}
            accessibilityState={isFocused ? { selected: true } : {}}
            testID={`${route.name}-tab`}
            onPress={onPress}
            className={`flex-1 ${dividerClassFlag} bg-white justify-center items-center pb-[20px]`}
          >
            <MenuItem
              activeIcon={routeConfig.active}
              idleIcon={routeConfig.inactive}
              menuTitle={routeConfig.title}
              selected={isFocused}
              badge={routeConfig.badge}
            />
          </PlatformPressable>
        );
      })}
    </View>
  );
};

export default BottomNavigation;

==> react-native-sj-prime-base-0.0.69.tgz: package/src/library/bottom-navigation.tsx <==
import { View } from 'react-native';
import { useLinkBuilder } from '@react-navigation/native';
import { PlatformPressable } from '@react-navigation/elements';
import React, { ReactNode } from 'react';
import MenuItem from './menu-item';

interface BottomNavigationProps {
  state: any;
  descriptors: any;
  navigation: any;
  config: {
    [key: string]: {
      active: ReactNode;
      inactive: ReactNode;
      title: string;
      order: number;
      badge?: {
        variant: 'dot' | 'new' | 'number';
        count?: number;
      };
    };
  };
  shadow?: boolean;
  divider?: boolean;
}

const BottomNavigation = ({
  state,
  descriptors,
  navigation,
  config,
  shadow = false,
  divider = false,
}: BottomNavigationProps) => {
  const { buildHref } = useLinkBuilder();
  const dividerClassFlag = divider ? 'border-t border-gray-100' : '';

  // order 기준으로 routes 정렬
  const sortedRoutes = [...state.routes].sort(
    (a, b) => config[a.name].order - config[b.name].order,
  );

  return (
    <View className="h-[86px]" style={{ flexDirection: 'row' }}>
      {sortedRoutes.map((route, index) => {
        const routeConfig = config[route.name];
        const isFocused =
          state.index === state.routes.findIndex((r) => r.key === route.key);

        const onPress = () => {
          const event = navigation.emit({
            type: 'tabPress',
            target: route.key,
            canPreventDefault: true,
          });

          if (!isFocused && !event.defaultPrevented) {
            navigation.navigate(route.name, route.params);
          }
        };

        return (
          <PlatformPressable
            key={route.key}
            pressOpacity={1}
            href={buildHref(route.name, route.params)}
            accessibilityState={isFocused ? { selected: true } : {}}
            testID={`${route.name}-tab`}
            onPress={onPress}
            className={`flex-1 ${dividerClassFlag} bg-white justify-center items-center`}
          >
            <MenuItem
              activeIcon={routeConfig.active}
              idleIcon={routeConfig.inactive}
              menuTitle={routeConfig.title}
              selected={isFocused}
              badge={routeConfig.badge}
            />
          </PlatformPressable>
        );
      })}
    </View>
  );
};

export default BottomNavigation;
